@@ -34,7 +34,7 @@ class Transformer_xl(pl.LightningModule):
     """
     def __init__(self,lr=3e-4,dim=128,heads=8,seq_len=512,mem_write_iters = 2,
                  max_batch_size=8,lmem_len = 256,mem_len = 256,memory_layers = [3,4,5],
-                 num_mem_kv = 128, depth = 5,T_max=500,attn_dropout=0.1, ff_glu = False, ff_dropout = 0.1, attn_layer_dropout = 0.1,num_tokens=8021,**kwargs):
+                 num_mem_kv = 128, depth = 5,T_max=500,attn_dropout=0.1, ff_glu = False, ff_dropout = 0.1, attn_layer_dropout = 0.1,num_tokens=8021,Autoregressive=False,**kwargs):
         """
 
         """
@@ -47,7 +47,7 @@ class Transformer_xl(pl.LightningModule):
         # else:
         #     self.tokenizer=tokenizer
 
-        model = MemoryTransformerXL(
+        self.model = MemoryTransformerXL(
             num_tokens = self.hparams.num_tokens,
             dim = self.hparams.dim,
             heads = self.hparams.heads,
@@ -64,7 +64,10 @@ class Transformer_xl(pl.LightningModule):
             
 
         )
-        self.model = AutoregressiveWrapper(model)
+        # 启用自动回归
+        if self.hparams.Autoregressive:
+            self.model = AutoregressiveWrapper(self.model)
+            
         #     self.model=model
         
         pass
@@ -73,17 +76,28 @@ class Transformer_xl(pl.LightningModule):
         输入原始长度数据,会自动进行切割并且返回编码和loss
         """
         # 对输出的状态进行拼接
-        allLoss=0
-        for i,(loss, is_last,logits) in enumerate(self.model(x, max_batch_size = self.hparams.max_batch_size, return_loss = return_loss)):
-          # print(loss, is_last,logits.size())
-            allLoss=allLoss+loss
-            if i==0:
-                out_logits=logits
-            else:
-                out_logits=torch.cat((out_logits,logits),1)
-        
-        loss=allLoss/x.size(0)
-        return out_logits,loss
+        if self.hparams.Autoregressive:
+            allLoss=0
+            for i,(loss, is_last,logits) in enumerate(self.model(x, max_batch_size = self.hparams.max_batch_size, return_loss = return_loss)):
+            # print(loss, is_last,logits.size())
+                allLoss=allLoss+loss
+                if i==0:
+                    out_logits=logits
+                else:
+                    out_logits=torch.cat((out_logits,logits),1)
+            
+            loss=allLoss/x.size(0)
+            return out_logits,loss
+        else:
+            for i,one in enumerate(x.split(self.hparams.seq_len,dim=1)):
+                # print(x)
+                if i==0:
+                    out_logits, mem1 = self.model(one)
+                    # out_logits=logits
+                else:
+                    logits, mem1 = self.model(one, memories = mem1)
+                    out_logits=torch.cat((out_logits,logits),1)
+            return out_logits
     def training_step(self, batch, batch_idx):
         """一次batch训练"""
         # training_step defined the train loop.
